FUNCTION drz_healp2fits_drizzle,healp_data,drizzle_st,elapsed_time=elapsed_time, $
                        weight=weight, $
                        healp_indexes=healp_indexes, $
                        silent=silent,partial=partial, pessimistic=pessimistic

;+
; NAME:
;	healp2fits_drizzle
; PURPOSE:
;       reproject healpix image onto a given fits header
;       using drizzling
; CATEGORY:
;       Planck Ancillary data ingestion
; CALLING SEQUENCE:
;	res=healp2fits_drizzle(healp_data,healp_header,fits_header)
; INPUTS:
;	healp_data  = healpix data (1D)
;       drizzle_st    = outputs a structure containing drizzle info
; OPTIONAL INPUT PARAMETERS:
; OUTPUTS:
; OPTIONAL OUTPUT PARAMETERS:
;	
; ACCEPTED KEY-WORDS:
;	elapsed_time  = elapsed time in the routine (sec)
;       weight        = output weight vector
;       healp_indexes = outputs array of healpix indices involved in projection
;       partial = if set output partial healpix
; COMMON BLOCKS:
;	None
; SIDE EFFECTS:
;       None
; RESTRICTIONS:
; PROCEDURE:
;	
; EXAMPLES
;    
; MODIFICATION HISTORY:
;	Written by J.P. Bernard 09/06/06
;-


;---------------------------------------------------------------
; parameter check
;---------------------------------------------------------------
IF N_PARAMS(0) LT 2 THEN BEGIN
  PRINT,'Calling Sequence: '
  PRINT,'vec=healp2fits_drizzle(healp_data,healp_header,fits_header'
  PRINT,'                 [,elapsed_time=][,weight=]'
  PRINT,'                 [,drizzle_st=][,use_drizzle_st=][,healp_indexes=][,/partial]'
  GOTO, the_end
ENDIF

time=systime(1)

naxis1=sxpar(drizzle_st.hfits,'NAXIS1')
naxis2=sxpar(drizzle_st.hfits,'NAXIS2')
blank=sxpar(drizzle_st.hfits,'BLANK')

dd=fltarr(naxis1,naxis2)
dd(*,*)=!drz_undef
dd=reform(dd,Naxis1*Naxis2)

nside=sxpar(drizzle_st.hhealpix,'NSIDE')
ordering=strtrim(sxpar(drizzle_st.hhealpix,'ORDERING'),2)

Npix=n_elements(drizzle_st.geom.pixel)
FOR i=0L,Npix-1 DO BEGIN
  IF ptr_valid(drizzle_st.geom(i).surface_inside) THEN BEGIN
      ind_nogood = where(float(healp_data(*(drizzle_st.geom(i).pix_inside))) eq float(!drz_undef) ,nnogood,complement=ind_good,ncomplement=ngood)
      if keyword_set(pessimistic) then begin
          if nnogood eq 0 then begin
              dd(drizzle_st.geom(i).pixel)=total(healp_data(*(drizzle_st.geom(i).pix_inside))*(*(drizzle_st.geom(i).surface_inside))) 
          endif
      endif else begin
          if ngood ne 0 then begin
              dd(drizzle_st.geom(i).pixel)=total(healp_data((*(drizzle_st.geom(i).pix_inside))(ind_good))*((*(drizzle_st.geom(i).surface_inside))(ind_good))) / total((*(drizzle_st.geom(i).surface_inside))(ind_good))
          endif
      endelse 
  ENDIF
ENDFOR

dd=reform(dd,[Naxis1,Naxis2])
the_end:

RETURN,dd

END
